@@ -7,6 +7,8 @@ from investing_algorithm_framework.core.order_executors import OrderExecutor, \
     BinanceOrderExecutor
 from investing_algorithm_framework.core.market_services import \
     MarketService, BinanceMarketService
+from investing_algorithm_framework.core.models.data_provider import \
+    TradingDataTypes, OrderBook, Ticker
 from investing_algorithm_framework.core.models import OrderSide, Order, \
     Position, TimeUnit, db, Portfolio, OrderType, OrderStatus
 from investing_algorithm_framework.app import App
@@ -14,7 +16,7 @@ from investing_algorithm_framework.globals import current_app
 from investing_algorithm_framework.configuration import Config
 from investing_algorithm_framework.views import *
 
-VERSION = (0, 8, 0, 'alpha', 0)
+VERSION = (0, 9, 0, 'alpha', 0)
 
 __all__ = [
     "App",
@@ -36,5 +38,8 @@ __all__ = [
     "Config",
     "MarketService",
     "BinanceMarketService",
-    "OrderStatus"
+    "OrderStatus",
+    "TradingDataTypes",
+    "Ticker",
+    "OrderBook"
 ]
