@@ -23,3 +23,14 @@ ORDER_SIDE_QUERY_PARAM = "order_side"
 STATUS_QUERY_PARAM = "status"
 POSITION_SYMBOL_QUERY_PARAM = "position"
 SYMBOL_QUERY_PARAM = "symbol"
+
+RESERVED_IDENTIFIERS = [
+    BINANCE
+]
+
+BINANCE_API_KEY = "binance_api_key"
+BINANCE_SECRET_KEY = "binance_secret_key"
+
+TRADING_SYMBOL = "TRADING_SYMBOL"
+
+CHECK_PENDING_ORDERS = "CHECK_PENDING_ORDERS"
