@@ -2,11 +2,25 @@ import logging
 from typing import List
 
 from investing_algorithm_framework.configuration import Config
+from investing_algorithm_framework.configuration.constants import \
+    TRADING_SYMBOL
 from investing_algorithm_framework.core.exceptions import OperationalException
 from investing_algorithm_framework.core.models import TimeUnit, OrderType, \
     db, OrderSide, OrderStatus
-from investing_algorithm_framework.core.workers import Scheduler
+from investing_algorithm_framework.core.models.data_provider import \
+    TradingDataTypes
+from investing_algorithm_framework.core.workers import Worker
 from investing_algorithm_framework.extensions import scheduler
+from investing_algorithm_framework.core.data_providers import\
+    DefaultDataProviderFactory, DataProvider
+from investing_algorithm_framework.configuration.constants import \
+    RESERVED_IDENTIFIERS
+from investing_algorithm_framework.core.market_services import \
+    DefaultMarketServiceFactory
+from investing_algorithm_framework.core.portfolio_managers import \
+    DefaultPortfolioManagerFactory
+from investing_algorithm_framework.core.order_executors import \
+    DefaultOrderExecutorFactory, OrderExecutor
 
 logger = logging.getLogger(__name__)
 
@@ -15,12 +29,13 @@ class AlgorithmContext:
     """
     The AlgorithmContext defines the context of an algorithm.
 
-    An algorithm consist out of an data provider and a set of
-    strategies that belong to the data provider.
+    An algorithm consist out of an data_provider provider and a set of
+    strategies that belong to the data_provider provider.
     """
     _config = None
     _workers = []
     _running_workers = []
+    _data_providers = {}
     _order_executors = {}
     _portfolio_managers = {}
     _market_services = {}
@@ -37,10 +52,10 @@ class AlgorithmContext:
     ):
 
         if function:
-            return Scheduler(function, worker_id, time_unit, interval)
+            return Worker(function, worker_id, time_unit, interval)
         else:
             def wrapper(f):
-                return Scheduler(f, worker_id, time_unit, interval)
+                return Worker(f, worker_id, time_unit, interval)
             return wrapper
 
     def initialize(self, config=None):
@@ -64,15 +79,11 @@ class AlgorithmContext:
 
         # Initialize the portfolio managers
         for portfolio_manager_key in self._portfolio_managers:
-            portfolio_manager = self._portfolio_managers[
-                portfolio_manager_key
-            ]
+            portfolio_manager = self._portfolio_managers[portfolio_manager_key]
             portfolio_manager.initialize(self)
 
         for order_executor_key in self._order_executors:
-            order_executor = self._order_executors[
-                order_executor_key
-            ]
+            order_executor = self._order_executors[order_executor_key]
             order_executor.initialize(self)
 
         self._initialized = True
@@ -101,8 +112,8 @@ class AlgorithmContext:
         algorithm context.
         """
 
-        assert isinstance(worker, Scheduler), OperationalException(
-            "Worker is not an instance of an Scheduler"
+        assert isinstance(worker, Worker), OperationalException(
+            "Worker is not an instance of an Worker"
         )
 
         for installed_worker in self._workers:
@@ -137,6 +148,11 @@ class AlgorithmContext:
         from investing_algorithm_framework.core.order_executors \
             import OrderExecutor
 
+        if order_executor in RESERVED_IDENTIFIERS:
+            raise OperationalException(
+                "Identifier of order executor is reserved"
+            )
+
         assert isinstance(order_executor, OrderExecutor), (
             'Provided object must be an instance of the OrderExecutor class'
         )
@@ -157,7 +173,7 @@ class AlgorithmContext:
 
     def get_order_executor(
             self, identifier=None, throw_exception: bool = True
-    ):
+    ) -> OrderExecutor:
         if identifier is None:
 
             if len(self._order_executors.keys()) == 0:
@@ -171,6 +187,14 @@ class AlgorithmContext:
 
         if identifier not in self._order_executors:
 
+            if identifier in RESERVED_IDENTIFIERS:
+                order_executor = DefaultOrderExecutorFactory\
+                    .of_market(identifier)
+                order_executor.initialize(self)
+                self._order_executors[order_executor.identifier] = \
+                    order_executor
+                return order_executor
+
             if throw_exception:
                 raise OperationalException(
                     f"No corresponding order executor found for "
@@ -181,6 +205,68 @@ class AlgorithmContext:
 
         return self._order_executors[identifier]
 
+    def add_data_provider(self, data_provider):
+        from investing_algorithm_framework.core.data_providers \
+            import DataProvider
+
+        if data_provider in RESERVED_IDENTIFIERS:
+            raise OperationalException(
+                "Identifier of data provider is reserved"
+            )
+
+        assert isinstance(data_provider, DataProvider), (
+            'Provided object must be an instance of the DataProvider class'
+        )
+
+        if data_provider.identifier in self._data_providers:
+            raise OperationalException("DataProvider id already exists")
+
+        self._data_providers[data_provider.identifier] = data_provider
+
+    @property
+    def data_providers(self) -> List:
+        data_providers = []
+
+        for data_provider in self._data_providers:
+            data_providers.append(data_provider)
+
+        return data_providers
+
+    def get_data_provider(
+            self, identifier=None, throw_exception: bool = True
+    ) -> DataProvider:
+
+        if identifier is None:
+
+            if len(self._data_providers.keys()) == 0:
+                raise OperationalException(
+                    "Algorithm has no data providers registered"
+                )
+
+            return self._data_providers[
+                list(self._data_providers.keys())[0]
+            ]
+
+        if identifier not in self._data_providers:
+
+            if identifier in RESERVED_IDENTIFIERS:
+                data_provider = DefaultDataProviderFactory\
+                    .of_identifier(identifier)
+
+                if data_provider is not None:
+                    self._data_providers[identifier.upper()] = data_provider
+                    return data_provider
+
+            if throw_exception:
+                raise OperationalException(
+                    f"No corresponding data provider found for "
+                    f"identifier {identifier}"
+                )
+
+            return None
+
+        return self._data_providers[identifier]
+
     def add_initializer(self, initializer):
         from investing_algorithm_framework.core.context \
             import AlgorithmContextInitializer
@@ -237,6 +323,16 @@ class AlgorithmContext:
 
         if identifier not in self._portfolio_managers:
 
+            if identifier in RESERVED_IDENTIFIERS:
+                portfolio_manager = DefaultPortfolioManagerFactory\
+                    .of_market(identifier)
+
+                portfolio_manager.initialize(self)
+                self._portfolio_managers[portfolio_manager.identifier] \
+                    = portfolio_manager
+
+                return portfolio_manager
+
             if throw_exception:
                 raise OperationalException(
                     f"No corresponding portfolio manager found for "
@@ -274,6 +370,15 @@ class AlgorithmContext:
     ):
         if market not in self._market_services:
 
+            if market in RESERVED_IDENTIFIERS:
+                market_service = DefaultMarketServiceFactory\
+                    .of_market(market)
+                market_service.initialize(self)
+
+                if market_service is not None:
+                    self._market_services[market.upper()] = market_service
+                    return market_service
+
             if throw_exception:
                 raise OperationalException(
                     f"No corresponding market service found for "
@@ -343,11 +448,13 @@ class AlgorithmContext:
         return order
 
     def create_market_buy_order(
-            self, identifier, symbol, amount, execute=False
+        self, identifier, symbol, amount_trading_symbol, execute=False
     ):
         portfolio_manager = self.get_portfolio_manager(identifier)
         order = portfolio_manager.create_order(
-            symbol=symbol, amount=amount, order_type=OrderType.MARKET.value
+            symbol=symbol,
+            amount=amount_trading_symbol,
+            order_type=OrderType.MARKET.value
         )
 
         if execute:
@@ -407,30 +514,155 @@ class AlgorithmContext:
         return portfolio_manager.get_pending_orders(symbol, lazy)
 
     def check_pending_orders(self, identifier=None, symbol: str = None):
-        portfolio_manager = self.get_portfolio_manager(identifier)
 
-        if portfolio_manager is not None:
+        if identifier is not None:
+
+            portfolio_manager = self.get_portfolio_manager(identifier)
+
             order_executor = \
                 self.get_order_executor(portfolio_manager.identifier)
 
             pending_orders = portfolio_manager.get_pending_orders(symbol)
 
             for pending_order in pending_orders:
-                status = order_executor.get_order_status()
+                status = order_executor.get_order_status(
+                    pending_order, self
+                )
 
                 if OrderStatus.SUCCESS.equals(status):
                     pending_order.set_executed()
                 else:
                     pending_order.update(db, {status: status.value})
+        else:
+
+            for portfolio_manager_key in self._portfolio_managers:
+                portfolio_manager = self._portfolio_managers[
+                    portfolio_manager_key
+                ]
+
+                pending_orders = portfolio_manager.get_pending_orders(symbol)
+
+                order_executor = self.get_order_executor(
+                    portfolio_manager.identifier
+                )
+
+                for pending_order in pending_orders:
+                    status = order_executor.get_order_status(
+                        pending_order, self
+                    )
+
+                    if OrderStatus.SUCCESS.equals(status):
+                        pending_order.set_executed()
+                    else:
+                        pending_order.update(db, {status: status.value})
+
+    def get_data(
+            self,
+            identifier,
+            trading_data_type=None,
+            target_symbol=None,
+            trading_symbol=None,
+            target_symbols: List = None
+    ):
+        data_provider = self.get_data_provider(identifier)
+
+        # Check if trading symbol is specified
+        if trading_symbol is None:
+            trading_symbol = self.config.get(TRADING_SYMBOL, None)
+
+            if trading_symbol is None:
+                raise OperationalException(
+                    "Trading symbol is not set. Either provide a "
+                    "'trading_symbol' param in the method or set "
+                    "the 'trading_symbol' attribute in the algorithm "
+                    "config."
+                )
+
+        if target_symbols is None and target_symbol is None \
+                and trading_data_type is not None:
+            raise OperationalException(
+                "You must either set the target symbol param or "
+                "target symbols param for this trading data type"
+            )
+
+        if TradingDataTypes.TICKER.equals(trading_data_type):
+
+            if target_symbols is not None:
+                tickers = []
+
+                for target_symbol in target_symbols:
+                    tickers.append(
+                        data_provider.provide_ticker(
+                            target_symbol=target_symbol,
+                            trading_symbol=trading_symbol,
+                            algorithm_context=self
+                        )
+                    )
+
+                return tickers
+
+            return data_provider.provide_ticker(
+                target_symbol=target_symbol,
+                trading_symbol=trading_symbol,
+                algorithm_context=self
+            )
+
+        if TradingDataTypes.ORDER_BOOK.equals(trading_data_type):
+
+            if target_symbols is not None:
+                tickers = []
+
+                for target_symbol in target_symbols:
+                    tickers.append(
+                        data_provider.provide_order_book(
+                            target_symbol=target_symbol,
+                            trading_symbol=trading_symbol,
+                            algorithm_context=self
+                        )
+                    )
+
+                return tickers
+
+            return data_provider.provide_order_book(
+                target_symbol=target_symbol,
+                trading_symbol=trading_symbol,
+                algorithm_context=self
+            )
+
+        if trading_data_type is None:
+
+            if target_symbols is not None:
+                raw_data = []
+
+                for target_symbol in target_symbols:
+                    raw_data.append(
+                        data_provider.provide_raw_data(
+                            target_symbol=target_symbol,
+                            trading_symbol=trading_symbol,
+                            algorithm_context=self
+                        )
+                    )
+
+                return raw_data
+
+            if target_symbol is not None:
+                return data_provider.provide_raw_data(
+                    target_symbol=target_symbol,
+                    trading_symbol=trading_symbol,
+                    algorithm_context=self
+                )
+
+            return data_provider.provide_raw_data(self)
+
 
     def get_unallocated_size(self, identifier):
         portfolio_manager = self.get_portfolio_manager(identifier)
         return portfolio_manager.unallocated
 
     def reset(self):
-        self._config = None
         self._workers = []
         self._running_workers = []
+        self._data_providers = {}
         self._order_executors = {}
         self._portfolio_managers = {}
         self._market_services = {}
